@@ -3,6 +3,7 @@
 #' Get all code types. Mainly useful as a reminder of what code types are
 #' available.
 #'
+#' @param code_type optional parameter to restrict output to a specific code type.
 #' @param date restrict output to code types modified after a given date in
 #'        yyyy-mm-dd format, e.g. "2010-12-01"
 #'
@@ -17,31 +18,31 @@
 #' \code{\link{icesVocab-package}} gives an overview of the package.
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' # Find code type for World Register of Marine Species (WoRMS)
 #' types <- getCodeTypeList()
 #' types[grep("worms", tolower(types$Description)),]
 #'
+#' # The code type "SpecWoRMS" can be used when calling getCodeTypeList()
+#' getCodeTypeList(code_type = "SpecWoRMS")
+#'# or using the guid
+#' getCodeTypeList(code_type = "f107b677-97ff-4cd9-b4ab-637bb6706066")
+#'
 #' findCodeType("worms", full = TRUE)
 #'
-#' # The code type "SpecWoRMS" can be used when calling getCodeList()
 #' }
 #' @export
 
-getCodeTypeList <- function(date = NULL) {
-
-  # base url
-  url <- "https://vocab.ices.dk/services/pox/GetCodeTypeList"
-
-  # if date supplied return list of code types modified after the given date
-  if (!is.null(date)) {
-    url <- sprintf(paste0(url, "/%s"), date)
-  }
+getCodeTypeList <- function(code_type = NULL, date = NULL) {
 
   # read url contents
-  xml <- readVocab(url)
-  # parse the text string returning a dataframe
-  out <- parseVocab(xml)
+  out <-
+    vocab_get_cached(
+      vocab_api("CodeType", codeType = code_type, modified = date)
+    )
+
+  # convert names
+  names(out) <- CamelCase(names(out))
 
   # return
   out
